Module lambda_calculus::arithmetic
[−]
[src]
Church-encoded numerals and arithmetic operations
Functions
| div |
Applied to two Church-encoded numbers it returns a Church-encoded pair with the result of their
division - the quotient and the remainder. It loops indefinitely if the divisor is |
| eq |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is egual to the second one. |
| factorial |
Applied to a Church-encoded number it yields its Church-encoded factorial. |
| geq |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is greater than or egual to the second one. |
| gt |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is greater than the second one. |
| is_zero |
Applied to a Church-encoded number it produces a Church-encoded boolean, indicating whether its argument is equal to zero. |
| leq |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is less than or egual to the second one. |
| lt |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is less than the second one. |
| mult |
Applied to two Church-encoded numbers it produces their product. |
| neq |
Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its first argument is not egual to the second one. |
| one |
Produces a Church-encoded number one. |
| plus |
Applied to two Church-encoded numbers it produces their sum. |
| pow |
Applied to two Church-encoded numbers it raises the first one to the power of the second one. |
| pred |
Applied to a Church-encoded number it produces its predecessor. |
| quot |
Applied to two Church-encoded numbers it returns a Church-encoded quotient of their division.
It loops indefinitely if the second argument is |
| rem |
Applied to two Church-encoded numbers it returns a Church-encoded remainder of their division.
It loops indefinitely if the second argument is |
| sub |
Applied to two Church-encoded numbers it subtracts the second one from the first one. |
| succ |
Applied to a Church-encoded number it produces its successor. |
| zero |
Produces a Church-encoded number zero. |