Function lambda_calculus::booleans::if_else [] [src]

pub fn if_else() -> Term

Applied to a Church encoded predicate and two terms it returns the first one if the predicate is true or the second one if the predicate is false.

if_else := λpab.p a b = λ λ λ 3 2 1