Functions

  • Applied to two Parigot-encoded numbers it produces their sum.
  • Applied to a Parigot-encoded number it produces a lambda-encoded boolean, indicating whether its argument is equal to zero.
  • Applied to two Parigot-encoded numbers it yields their product.
  • Produces a Parigot-encoded number one.
  • Applied to a Parigot-encoded number it produces its predecessor.
  • Applied to two Church-encoded numbers it subtracts the second one from the first one.
  • Applied to a Parigot-encoded number it produces its successor.
  • Produces a Parigot-encoded number zero; equivalent to boolean::fls.