Module lambda_calculus::list
[−]
[src]
Functions
| append |
Applied to 2 Church lists it concatenates them. |
| cons |
Equivalent to |
| filter |
Applied to a predicate and a Church list it filters the list based on the predicate. |
| foldl |
Applied to a function, a starting value and a Church list it performs a left fold on the list. |
| foldr |
Applied to a function, a starting value and a Church list it performs a right fold on the list. |
| head |
Equivalent to |
| index |
Applied to a Church number |
| length |
Applied to a Church list it returns its Church-encoded length. |
| list |
Applied to a Church number |
| map |
Applied to a function and a Church list it maps the function over it. |
| nil |
Equivalent to |
| null |
Applied to a Church list it determines if it is empty. |
| reverse |
Reverses a Church list. |
| tail |
Equivalent to |