Term

Enum Term 

pub enum Term {
    Var(usize),
    Abs(Box<Term>),
    App(Box<(Term, Term)>),
}
A lambda term that is either a variable with a De Bruijn index, an abstraction over a term or an applicaction of one term to another.

Variants



Var(usize)

a variable



Abs(Box<Term>)

an abstraction



App(Box<(Term, Term)>)

an application

Implementations

Source

impl Term

pub fn unvar(self) -> Result<usize, TermError>

Returns a variable’s De Bruijn index, consuming it in the process.

Example
use lambda_calculus::*;

assert_eq!(Var(1).unvar(), Ok(1));
Errors

Returns a TermError if self is not a Variable.

pub fn unvar_ref(&self) -> Result<&usize, TermError>

Returns a reference to a variable’s De Bruijn index.

Example
use lambda_calculus::*;

assert_eq!(Var(1).unvar_ref(), Ok(&1));
Errors

Returns a TermError if self is not a Variable.

pub fn unvar_mut(&mut self) -> Result<&mut usize, TermError>

Returns a mutable reference to a variable’s De Bruijn index.

Example
use lambda_calculus::*;

assert_eq!(Var(1).unvar_mut(), Ok(&mut 1));
Errors

Returns a TermError if self is not a Variable.

pub fn unabs(self) -> Result<Term, TermError>

Returns an abstraction’s underlying term, consuming it in the process.

Example
use lambda_calculus::*;

assert_eq!(abs(Var(1)).unabs(), Ok(Var(1)));
Errors

Returns a TermError if self is not an Abstraction.

pub fn unabs_ref(&self) -> Result<&Term, TermError>

Returns a reference to an abstraction’s underlying term.

Example
use lambda_calculus::*;

assert_eq!(abs(Var(1)).unabs_ref(), Ok(&Var(1)));
Errors

Returns a TermError if self is not an Abstraction.

pub fn unabs_mut(&mut self) -> Result<&mut Term, TermError>

Returns a mutable reference to an abstraction’s underlying term.

Example
use lambda_calculus::*;

assert_eq!(abs(Var(1)).unabs_mut(), Ok(&mut Var(1)));
Errors

Returns a TermError if self is not an Abstraction.

pub fn unapp(self) -> Result<(Term, Term), TermError>

Returns a pair containing an application’s underlying terms, consuming it in the process.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).unapp(), Ok((Var(1), Var(2))));
Errors

Returns a TermError if self is not an Application.

pub fn unapp_ref(&self) -> Result<(&Term, &Term), TermError>

Returns a pair containing references to an application’s underlying terms.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).unapp_ref(), Ok((&Var(1), &Var(2))));
Errors

Returns a TermError if self is not an Application.

pub fn unapp_mut(&mut self) -> Result<(&mut Term, &mut Term), TermError>

Returns a pair containing mutable references to an application’s underlying terms.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).unapp_mut(), Ok((&mut Var(1), &mut Var(2))));
Errors

Returns a TermError if self is not an Application.

pub fn lhs(self) -> Result<Term, TermError>

Returns the left-hand side term of an application. Consumes self.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).lhs(), Ok(Var(1)));
Errors

Returns a TermError if self is not an Application.

pub fn lhs_ref(&self) -> Result<&Term, TermError>

Returns a reference to the left-hand side term of an application.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).lhs_ref(), Ok(&Var(1)));
Errors

Returns a TermError if self is not an Application.

pub fn lhs_mut(&mut self) -> Result<&mut Term, TermError>

Returns a mutable reference to the left-hand side term of an application.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).lhs_mut(), Ok(&mut Var(1)));
pub fn rhs(self) -> Result<Term, TermError>

Returns the right-hand side term of an application. Consumes self.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).rhs(), Ok(Var(2)));
Errors

Returns a TermError if self is not an Application.

pub fn rhs_ref(&self) -> Result<&Term, TermError>

Returns a reference to the right-hand side term of an application.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).rhs_ref(), Ok(&Var(2)));
Errors

Returns a TermError if self is not an Application.

pub fn rhs_mut(&mut self) -> Result<&mut Term, TermError>

Returns a mutable reference to the right-hand side term of an application.

Example
use lambda_calculus::*;

assert_eq!(app(Var(1), Var(2)).rhs_mut(), Ok(&mut Var(2)));
Errors

Returns a TermError if self is not an Application.

pub fn is_supercombinator(&self) -> bool

Returns true if self is a supercombinator.

Example
use lambda_calculus::*;

let term1 = abs(app(Var(1), abs(Var(1)))); // λ 1 (λ 1)
let term2 = app(abs(Var(2)), abs(Var(1))); // (λ 2) (λ 1)

assert_eq!(term1.is_supercombinator(), true);
assert_eq!(term2.is_supercombinator(), false);
pub fn max_depth(&self) -> u32

Returns the maximum depth of lambda abstractions in the given Term.

Example
use lambda_calculus::*;

assert_eq!(abs(Var(1)).max_depth(), 1);
pub fn is_isomorphic_to(&self, other: &Term) -> bool

Returns true if self is structurally isomorphic to other.

Example
use lambda_calculus::*;

let term1 = abs(Var(1)); // λ 1
let term2 = abs(Var(2)); // λ 2
let term3 = abs(Var(1)); // λ 1

assert_eq!(term1.is_isomorphic_to(&term2), false);
assert_eq!(term1.is_isomorphic_to(&term3), true);
pub fn has_free_variables(&self) -> bool

Returns true if self has any free vairables.

Example
use lambda_calculus::*;

let with_freevar = abs(Var(2));     // λ 2
let without_freevar = abs(Var(1));  // λ 1

assert!(with_freevar.has_free_variables());
assert!(!without_freevar.has_free_variables());
pub fn max_free_index(&self) -> usize

Calculates the maximum index of any free variable in the term.

The result corresponds to the number of names Context must supply to bind them all.

pub fn with_context<'a>(&'a self, ctx: &'a Context) -> impl Display + 'a

Returns a helper struct that allows displaying the term with a given context.

Example
use lambda_calculus::{*, term::Context};

let term = abs(Var(2)); // λa.b
let ctx = Context::new(&["x"]); // Predefine "x" as a free variable

// The context defines `Var(2)` as "x" instead of the default "b"
assert_eq!(term.with_context(&ctx).to_string(), "λa.x");
Source

impl Term

pub fn apply(&mut self, rhs: &Term) -> Result<(), TermError>

Applies a Term to self via substitution and variable update.

Example
use lambda_calculus::*;

let mut term1  = parse(&"λλ42(λ13)", DeBruijn).unwrap();
let term2      = parse(&"λ51", DeBruijn).unwrap();
let result     = parse(&"λ3(λ61)(λ1(λ71))", DeBruijn).unwrap();

term1.apply(&term2);

assert_eq!(term1, result);
Errors

Returns a TermError if self is not an Abstraction.

pub fn reduce(&mut self, order: Order, limit: usize) -> usize

Performs β-reduction on a Term with the specified evaluation Order and an optional limit on the number of reductions (0 means no limit) and returns the number of performed reductions.

Example
use lambda_calculus::*;

let mut expression = parse(&"(λa.λb.λc.b (a b c)) (λa.λb.b)", Classic).unwrap();
let reduced        = parse(&"λa.λb.a b", Classic).unwrap();

expression.reduce(NOR, 0);

assert_eq!(expression, reduced);