Module boolean
Source Expand description
- and
- Applied to two lambda-encoded booleans it returns their lambda-encoded conjunction.
- fls
- A lambda-encoded boolean
false. - if_else
- Applied to a lambda-encoded predicate and two terms it returns the first one if the predicate
is true or the second one if the predicate is false.
- imply
- Applied to two lambda-encoded booleans it returns their lambda-encoded implication.
- nand
- Applied to two lambda-encoded booleans it returns their lambda-encoded alternative denial.
- nor
- Applied to two lambda-encoded booleans it returns their lambda-encoded joint denial.
- not
- Applied to a lambda-encoded boolean it returns its lambda-encoded negation.
- or
- Applied to two lambda-encoded booleans it returns their lambda-encoded disjunction.
- tru
- A lambda-encoded boolean
true. - xnor
- Applied to two lambda-encoded booleans it returns their lambda-encoded exclusive joint denial
(
nor); it is also known as iff. - xor
- Applied to two lambda-encoded booleans it returns their lambda-encoded exclusive disjunction.