Lambda-encoded result type
Functions
- and_
then - Applied to a lambda-encoded
Resultand a function that returns a lambda-encodedResult, it applies the function to the contents of theResultif it isOk. - err
- Applied to an argument it consumes it and produces a lambda-encoded
Result::Errthat contains it. - is_err
- Applied to a lambda-encoded
Resultit produces a lambda-encoded boolean indicating whether it isResult::Err. - is_ok
- Applied to a lambda-encoded
Resultit produces a lambda-encoded boolean indicating whether it isResult::Ok. - map
- Applied to a function and a lambda-encoded
Resultit applies the function to the contents of theResultif it isOk. - map_err
- Applied to a function and a lambda-encoded
Resultit applies the function to the contents of theResultif it isErr. - ok
- Applied to an argument it consumes it and produces a lambda-encoded
Result::Okthat contains it. - option_
err - Applied to a lambda-encoded
Resultit produces a lambda-encodedOptioncontaining theErrvalue. - option_
ok - Applied to a lambda-encoded
Resultit produces a lambda-encodedOptioncontaining theOkvalue. - unwrap_
or - Applied to a
Termand a lambda-encodedResultit returns the value inside theOkor the first argument if theResultis notOk.