Lambda-encoded result type

Functions

  • Applied to a lambda-encoded Result and a function that returns a lambda-encoded Result, it applies the function to the contents of the Result if it is Ok.
  • Applied to an argument it consumes it and produces a lambda-encoded Result::Err that contains it.
  • Applied to a lambda-encoded Result it produces a lambda-encoded boolean indicating whether it is Result::Err.
  • Applied to a lambda-encoded Result it produces a lambda-encoded boolean indicating whether it is Result::Ok.
  • Applied to a function and a lambda-encoded Result it applies the function to the contents of the Result if it is Ok.
  • Applied to a function and a lambda-encoded Result it applies the function to the contents of the Result if it is Err.
  • Applied to an argument it consumes it and produces a lambda-encoded Result::Ok that contains it.
  • Applied to a lambda-encoded Result it produces a lambda-encoded Option containing the Err value.
  • Applied to a lambda-encoded Result it produces a lambda-encoded Option containing the Ok value.
  • Applied to a Term and a lambda-encoded Result it returns the value inside the Ok or the first argument if the Result is not Ok.