Module lambda_calculus::list
[−]
[src]
Functions
| cons |
Equivalent to pair(); applied to two terms it returns them encoded as a list. |
| head |
Equivalent to first(); applied to a Church-encoded list it returns its first element. |
| is_nil |
Applied to a Church-encoded list it determines if it is empty. |
| nil |
Equivalent to fls(); produces a Church-encoded nil, the last link of a Church-encoded list. |
| tail |
Equivalent to second(); applied to a Church-encoded list it returns a new list with all its elements but the first one. |