Module lambda_calculus::term
[−]
[src]
Reexports
pub use self::Term::*; |
pub use self::Notation::*; |
Enums
| Error |
An error that can be returned when an inapplicable function is applied to a term. |
| Notation |
The notation used for parsing and displaying purposes. |
| Term |
A lambda term that is either a variable with a De Bruijn index, an abstraction over a term or an applicaction of one term to another. |
Constants
| LAMBDA |
The character used to display lambda abstractions. The default is the Greek letter 'λ', but it
can also be set to a '\' (backslash) using |
Functions
| abs |
Wraps a |
| app |
Produces an |